@@ -170,6 +170,11 @@ char *              remove_special_dirs_from_path (const char *path);
      
 GnomeVFSURI *       new_uri_from_path             (const char *path);
 
+GnomeVFSResult      resolve_all_symlinks_uri      (GnomeVFSURI *uri,
+						   GnomeVFSURI **result_uri);
+
+GnomeVFSResult      resolve_all_symlinks          (const char  *text_uri,
+						   char       **resolved_text_uri);
 
 #define errno_to_string() (gnome_vfs_result_to_string (gnome_vfs_result_from_errno ()))
 
