@@ -89,6 +89,7 @@ typedef enum { /*< skip >*/
 
 
 typedef enum { /*< skip >*/
+	GTH_VIEW_MODE_VOID,               /* No text at all. */
 	GTH_VIEW_MODE_LABEL,              /* Display label. */
 	GTH_VIEW_MODE_COMMENTS,           /* Display comment. */
  	GTH_VIEW_MODE_COMMENTS_OR_TEXT,   /* When a comment is present do
@@ -158,6 +159,12 @@ typedef enum { /*< skip >*/
 } GthFrameStyle;
 
 
+typedef enum { /*< skip >*/
+	GTH_PREVIEW_CONTENT_IMAGE,
+	GTH_PREVIEW_CONTENT_DATA,
+	GTH_PREVIEW_CONTENT_COMMENT,
+} GthPreviewContent;
+
 typedef void (*ErrorFunc)      (gpointer data);
 
 typedef void (*DoneFunc)       (gpointer data);
